# -*- coding: utf-8 -*- # Языковая кодировка UTF-8
from nltk.tokenize.punkt import PunktSentenceTokenizer, PunktParameters

from .data.abbreviations import sorted_abbrev


def sent_tokenize_with_abbr(text):
    text = text.replace('\n', '')
    # Шаг 1:Cоздаём объект PunktParameters, который будет хранить наши настройки.
    punct_param = PunktParameters()
    # Шаг 2: Добавление сокращений в параметр токенизатора abbrev_types.
    # Это позволяет токенизатору учитывать их и не считать точку после этих сокращений как конец предложения.
    punct_param.abbrev_types = sorted_abbrev
    # Шаг 3: Создание кастомного токенизатора с учётом настроек
    sentence_splitter_with_abbr = PunktSentenceTokenizer(punct_param)

    # Шаг 5: Токенизация текста на предложения
    # Используем наш кастомный токенизатор для разбиения текста на предложения.
    sentences = list(sentence_splitter_with_abbr.tokenize(text))
    return sentences


if __name__ == "__main__":
    # Текст для примера (сгенерирован ИИ)
    input_text = """В огромном городе, где небоскрёбы касались облаков, жила девушка по имени Лиза. Она работала в 
    необычной организации под названием "Луч Света". Эта организация ставила перед собой амбициозную цель — помочь 
    каждому человеку на Земле и сделать мир добрее. Каждое утро Лиза приходила в светлый офис, наполненный зелёными 
    растениями и солнечными лучами, проникающими через огромные окна. Она садилась за свой стол и начинала день с 
    того, что проверяла письма и сообщения от людей со всего мира. Кто-то нуждался в помощи с оплатой медицинских 
    счетов, кто-то искал поддержку в трудную минуту, а кто-то просто хотел поделиться своей радостью. Однажды Лиза 
    получила письмо от маленькой девочки из далёкой деревни. Девочка писала, что её мама тяжело больна, 
    и она не знает, как ей помочь. Лиза немедленно связалась с коллегами, и вскоре команда врачей отправилась в ту 
    самую деревню, чтобы оказать необходимую помощь. Через несколько недель пришло радостное сообщение: мама девочки 
    пошла на поправку. Но "Луч Света" занимался не только экстренной помощью. Они организовывали образовательные 
    программы для детей из бедных семей, строили парки и школы, проводили акции по защите окружающей среды. Лиза 
    особенно гордилась проектом, который они запустили в Африке: благодаря усилиям команды, в нескольких деревнях 
    появились чистая вода и солнечные батареи. Однажды к ним в офис пришёл пожилой человек. Он выглядел растерянным и 
    усталым. Лиза подошла к нему и узнала, что его зовут Иван. Иван потерял всё: дом, семью, работу. Он чувствовал 
    себя одиноким и беспомощным. Лиза пригласила его в свой кабинет, выслушала его историю и пообещала помочь. В 
    течение нескольких дней команда "Луча Света" нашла для Ивана временное жильё, помогла восстановить документы и 
    устроить его на работу. Иван был бесконечно благодарен и часто заходил в офис, чтобы поделиться своими успехами. 
    Каждый вечер Лиза возвращалась домой с чувством выполненного долга. Она знала, что её работа имеет значение, 
    что люди, которым она помогла, снова верят в добро и справедливость. И хотя задачи, стоящие перед "Лучом Света", 
    казались порой непосильными, Лиза и её коллеги не сдавались. Они верили, что капля добра способна вызвать 
    настоящий океан перемен. Так проходили дни, месяцы и годы. Лиза продолжала работать в "Луче Света", 
    оставаясь верной своей мечте — сделать мир лучше. Она знала, что впереди ещё много вызовов, но с каждым добрым 
    делом, с каждой спасённой жизнью, с каждой улыбкой на лице благодарного человека мир становился чуть светлее и 
    добрее."""
    # Удаление символов новой строки
    input_text = input_text.replace('\n', '')

    print(sent_tokenize_with_abbr(input_text))
