# -*- coding: utf-8 -*- # Языковая кодировка UTF-8

import re

conjunctions_set = {
    'а', 'а ведь', 'а еще', 'а и то', 'а именно', 'а не то', 'а не то что',
    'а не только', 'а равно и', ', а также', 'а то', 'а то и', 'абы',
    'благо что', 'благо, что', 'благодаря тому, что', 'благодаря чему',
    'благодаря тому что', ' будто', ', будто бы', ', будь то',
    'в знак того, что', 'в надежде на то, что', 'в отношении того, что',
    'в подтверждение того, что', 'в противном случае',
    'в расчете на то, что', 'в результате того, что', 'в результате чего',
    'в связи с тем, что', 'в связи с тем что', 'в связи с чем',
    'в силу того, что', 'в силу того что', 'в случае, если',
    'в случае если', 'в то время как', 'в том духе, что',
    'в том отношении, что', 'в том смысле, что', 'в том числе',
    'в том числе и', 'ввиду того что', 'ввиду того, что',
    'ведь', 'вместо того чтоб', 'вместо того, чтоб', 'вместо того чтобы',
    'вместо того, чтобы', 'во всяком случае', 'во имя того, чтобы',
    'вопреки', 'вопреки тому что', 'вопреки тому, что', 'вплоть до того что',
    'впрочем', 'вплоть до того, что', 'вроде бы',
    'вроде как', 'вроде того что', 'вроде того, что',
    'вроде того, чтоб', 'вроде того, чтобы', 'все равно, как',
    'все равно как', 'все ж таки', 'все же', 'все-таки',
    'вследствие того что', 'вследствие того, что', 'вследствие чего',
    'где б ни', 'где бы ни', 'где ни', 'да', 'да ведь', 'да еще',
    'да еще и', 'да и', 'да и то', 'да как', 'дабы', 'даже', 'в силу чего', 'даром'
    'даром что', 'даром, что', 'для того чтоб', 'для того чтобы', 'для того, чтоб',
    'для того, чтобы', 'до тех пор пока', 'до тех пор, пока', 'до того как',
    'до того, как', 'добро', 'добро бы', 'доколе', 'доколь',
    'докуда', 'едва', 'едва лишь', 'едва только', 'ежели', 'если', 'если б',
    'если б и', 'если б не', 'если бы', 'если бы и', 'если бы не', 'если не',
    'за исключением', 'за исключением того что',
    'за исключением того, что', 'за счет того что', 'затем что', 'затем, что',
    'затем чтоб', 'затем чтобы', 'затем, чтоб', 'затем, чтобы',
    'зато', 'значит', 'и', 'и то', 'ибо', 'из-за того что', 'из-за того, что',
    'или', 'иль', 'именно', 'ин', 'иначе', 'исходя из того что',
    'исходя из того, что', 'итак', 'к тому ж', 'к тому же', 'кабы', 'как',
    ', как будто', ', как будто бы', 'как бы', 'как бы ни', 'как вдруг',
    'как все равно', 'как если бы', 'как и', 'как ни', 'как скоро',
    'как только', 'какой бы ни', 'какой ни', 'когда', 'когда б',
    'когда б не', 'когда б ни', 'когда бы', 'когда бы не', 'когда бы ни',
    'когда ни', 'коли', 'коль', 'коль скоро', 'кроме как', 'кроме того что',
    'кроме того, что', 'кто б ни', 'кто бы ни', 'кто ни', 'куда б ни',
    'куда бы ни', 'куда ни', 'либо', 'лишь бы', 'лишь бы только',
    'лишь только', 'лишь только б', 'лишь только бы', 'мало того что',
    'мало того, что', 'меж тем как', 'меж тем, как', 'между тем как',
    'на случай если', 'на случай, если', 'на том основании что',
    'на том основании, что', 'на тот случай если',
    'на тот случай, если', 'на что', 'наподобие того как',
    'наподобие того, как', 'наподобие того что', 'наподобие того, что',
    'напротив', 'насчет того что', 'насчет того, что', 'начиная с того что',
    'начиная с того, что', 'не то', 'не то что', 'не то,что',
    'невзирая на то что', 'невзирая на то, что', 'нежели',
    'независимо от того что', 'независимо от того, что', 'несмотря на то что',
    'несмотря на то, что', 'нет бы', 'нет того, чтоб',
    'нет того, чтобы', 'нет чтоб', 'нет, чтоб', 'нет чтобы', 'нет, чтобы',
    'нешто', 'ни', 'но', 'но и', 'но и то', 'ну', 'однако',
    'относительно того что', 'относительно того, что', 'оттого что',
    'оттого, что', 'отчего', 'перед тем как', 'перед тем, как',
    'по мере того как', 'по мере того, как', 'по поводу того что',
    'по поводу того, что', 'по причине того, что', 'по причине того что',
    'по случаю того что', 'по случаю того, что', 'по той причине что',
    'по той причине, что', 'по тому поводу, что', 'по тому поводу что',
    'под предлогом того, что', 'под предлогом, что', 'под тем предлогом, что',
    'подобно тому как', 'подобно тому, как', 'поелику', 'пока', 'пока не',
    'покамест', 'покамест не', 'покуда', 'помимо того что', 'помимо того, что',
    'понеже', 'поскольку', 'после того как', 'после того, как',
    'после чего', 'постольку', 'постольку поскольку', 'потому', 'потому как',
    'потому что', 'потому, что', 'почему', ', правда', 'прежде нежели',
    'прежде чем', 'при всем том', 'при всем том, что', 'при том что',
    'притом', 'причем', 'промеж тем', 'просто', 'пускай', 'пускай бы',
    'пусть', 'пусть бы', 'равно', 'равно как', 'равно как и',
    'ради того чтоб', 'ради того чтобы', 'ладно бы',
    'ради того, чтоб', 'ради того, чтобы', ', раз', 'разве', 'раньше чем',
    'ровно', 'ровно бы', 'с таким расчетом, чтоб', 'с таким расчетом, чтобы',
    'с тем расчетом, чтоб', 'с тем расчетом, чтобы', 'с тем чтоб',
    'с тем чтобы', 'с тем, чтоб', 'с тем, чтобы', 'с тех пор как',
    'с тех пор, как', 'с той разницей, что', 'с той целью, чтоб',
    'с той целью, чтобы', 'с целью, чтоб', 'с целью, чтобы', 'сиречь',
    'сколь бы ни', 'сколь ни', 'сколько б ни', 'сколько бы ни', 'сколько ни',
    'следовательно', 'следственно', 'словно', 'словно б', 'словно бы',
    'словно как', 'судя по тому, что', 'так', 'так же', 'так же как',
    'так же как и', ', так и', 'так как', 'т.к.', 'т. к.', 'так что', 'тем',
    'тем более что', 'тем не менее', 'теперь', 'то', 'то бишь', 'то есть',
    'тогда как', 'тогда', 'тоже', 'токмо', 'только', 'только б', 'только бы',
    'только лишь', 'только что', 'точно', 'точно бы', 'уж на что', 'хоть',
    'хоть бы', 'хоть и', 'хотя', 'хотя б', 'хотя бы', 'хотя и', 'чем',
    'чем бы', ', что', 'чтоб', 'чтобы', 'чуть', 'чуть только', 'яко', 'якобы',
    'зачем', ', вроде', 'не столько', 'не только', 'не то чтобы', 'то ли',
    'при условии что', 'при условии, что', 'покуда не', 'также как',
    'как только', 'пoсле того как', 'пoсле того, как', 'до того как',
    'до того, как', ', ровно как', 'если даже', 'даже если', 'в то время как',
    'до того', 'как будто', 'как будто бы', 'как бы', 'как бы не', 'как вдруг',
    'как то', 'как только', 'между тем как', 'перед тем как', 'после того как',
    'потому как', 'равно как', 'с тех пор как', 'тогда как'
}

# Снова преобразуем в список
conjunctions_list = list(conjunctions_set)

# Сортируем единицы по длине от большего к меньшему
conjunctions_list.sort(key=len, reverse=True)

# Создаем регулярное выражение
pattern = re.compile(r'\b(?:' + '|'.join(map(re.escape, conjunctions_list)) + r')\b')

text = ''''
Теперь программа должна учитывать, но слова после союза в правом окружении. Пожалуйста, проверьте, соответствует ли это вашим ожиданиям. а не только', 'а равно и', ', а также', 'а то', 'а то и', 'абы',
    'благо что', 'благо, что', 'благодаря тому, что', 'благодаря чему', 'благодаря тому что',
'''

if __name__ == '__main__':
    # Проверяем!
    lowercase_text = text.lower()
    found_conjunctions = [m.group() for m in pattern.finditer(lowercase_text)]
    print(found_conjunctions)
    print(len(found_conjunctions))
