# -*- coding: utf-8 -*- # Языковая кодировка UTF-8

import re

prepositions_set = {
    'а-ля', 'без', 'без ведома', 'безо', 'благодаря', 'близ',
    'близко от', 'близь', 'в', 'в виде', 'в зависимости от', 'в интересах',
    'в качестве', 'в лице', 'в отношении', 'в пользу',
    'в преддверии', 'в продолжение', 'в результате', 'в роли', 'в связи с',
    'в силу', 'в случае', 'в соответствии с', 'в течение', 'в целях',
    'в честь', 'вблизи', 'ввиду', 'вглубь',  'вдоль',
    'вдоль по', 'взамен', 'включая', 'вкруг', 'вместо', 'вне', 'внизу',
    'внутри', 'внутрь', 'во', 'во имя', 'во славу', 'вовнутрь', 'возле',
    'вокруг', 'вопреки', 'вослед', 'впереди', 'вплоть до', 'впредь до',
    'вразрез', 'вроде', 'вслед', 'вслед за', 'вследствие',
    'выше', 'для', 'до', 'за', 'за вычетом', 'за исключением', 'за счёт',
    'заместо', 'из', 'из-за', 'из-под', 'из-подо', 'изнутри',
    'изо', 'исключая', 'исходя из', 'к', 'касаемо', 'касательно', 'ко',
    'кроме', 'кругом', 'лицом к лицу с', 'меж', 'между', 'мимо', 'на',
    'на благо', 'на виду у', 'на глазах у', 'на предмет', 'навроде',
    'навстречу', 'над', 'надо', 'наподобие', 'напротив', 'наряду с',
    'насчёт', 'начиная с', 'не без', 'не считая', 'невзирая на',
    'недалеко от', 'независимо от', 'несмотря', 'несмотря на', 'о',
    'об', 'обо', 'от', 'от имени', 'от лица', 'относительно', 'ото',
    'перед', 'передо', 'по', 'по линии', 'по мере', 'по направлению к',
    'по отношению к', 'по поводу', 'по причине', 'по случаю',
    'по сравнению с', 'поблизости от',  'поверх', 'под', 'под видом',
    'под эгидой', 'подле', 'подо', 'подобно', 'позади', 'помимо',
    'поперёк', 'порядка', 'посереди', 'посередине', 'посерёдке',
    'посередь', 'после', 'посреди', 'посредине', 'посредством', 'пред',
    'предо', 'прежде', 'при', 'при помощи', 'применительно к', 'про',
    'промеж', 'промежду', 'против', 'путём', 'ради', 'рядом с', 'с',
    'с ведома', 'с помощью', 'с прицелом на', 'с точки зрения', 'с целью',
    'сверх', 'свыше', 'середи', 'середь', 'сквозь', 'следом за',
    'смотря по', 'со', 'согласно', 'спустя', 'среди', 'средь', 'сродни',
    'судя по', 'у', 'через', 'черезо', 'чрез', 'в условиях', 'в расчете на',
    'в направлении', 'на пути ко', 'в сравнении с', 'совокупно с',
    'в связи со', 'сравнительно с', 'сообща с', 'во время', 'в области',
    'по направлению ко', 'в отличие от', 'в сравнении со', 'начиная от',
    'вдобавок ко', 'при всем', 'рядом со', 'соразмерно со',
    'в дополнение к', 'на пути', 'в смысле', 'в форме', 'вместе с',
    'в направлении ко', 'в процессе', 'в сопоставлении с', 'на протяжении',
    'в сторону', 'под предлогом', 'наряду со', 'на путях ко',
    'на сторону', 'поодаль от', 'в обмен на', 'на основе', 'на случай',
    'в плане', 'в сообществе с', 'на базе', 'на путях к', 'сообразно',
    'согласно с', 'в аспекте', 'в противовес', 'в память',
    'в противоположность', 'по адресу', 'в отдалении от', 'в предвкушении',
    'наравне с', 'в соответствии со', 'в счет', 'чрезо', 'ценою',
    'соответственно с', 'во избежание', 'соразмерно с',
    'применительно ко', 'соответственно', 'к числу',
    'не говоря об', 'на смену', 'волею', 'совместно с', 'при посредстве',
    'сравнительно со', 'на фоне', 'на основании', 'неподалеку от',
    'при всей', 'в заключение', 'не до', 'в унисон с', 'не говоря о',
    'невдалеке от', 'за счет', 'во исполнение', 'не в пример',
    'в направлении к', 'при всех', 'в обход', 'по части', 'в ряду',
    'в порядке', 'согласно со', 'не говоря обо', 'вместе со', 'плюс к',
    'вдобавок к', 'вдогонку', 'минуя', 'по пути', 'в разрезе', 'в районе',
    'начиная со', 'в угоду', 'типа', 'на почве', 'считая', 'с учетом',
    'на стороне', 'совместно со', 'вблизи от', 'по аналогии со', 'из числа',
    'по сравнению со', 'в рамках', 'в составе', 'со стороны', 'на грани',
    'по праву', 'на уровне', 'на пути к', 'сообразно со', 'в ходе', 'в число',
    'сообща со', 'плюс ко', 'во главе с', 'в знак', 'в завершение',
    'вне зависимости от', 'что до', 'в меру', 'в ответ на',
    'по направлению', 'по прошествии', 'насчет', 'в духе',
    'соответственно со', 'в свете', 'в стороне от', 'вперед',
    'в сопровождении', 'по вине', 'вдалеке от', 'в согласии с', 'на манер',
    'под знаком', 'в числе', 'сообразно с', 'при условии', 'путем',
    'по аналогии с', 'по отношению ко', 'по истечении', 'наравне со',
    'ценою', 'вдали от', 'снаружи', 'вверху', 'силами', 'спереди', 'поперек',
    'во главе', 'вверху'
}

prepositions_list = list(prepositions_set)

prepositions_list.sort(key=len, reverse=True)
pattern = re.compile(r'\b(?:' + '|'.join(map(re.escape, prepositions_list)) + r')\b')

text = """"
Теперь программа должна учитывать отметим, что слова после союза в правом окружении. Пожалуйста, проверьте, соответствует ли это вашим ожиданиям.
"""

if __name__ == "__main__":
    lowercase_text = text.lower()

    found_prepositions = [m.group() for m in pattern.finditer(lowercase_text)]

    print(found_prepositions)
    print(len(found_prepositions))
