# -*- coding: utf-8 -*- # Языковая кодировка UTF-8
import ast

from colorama import Fore, Style
from rich.console import Console
from rich.table import Table

from ..core.utils import wait_for_enter_to_analyze
from ..explicitation.named_entities_extraction import extract_entities

console = Console()


def single_naming_frequency(text, show_analysis=True):
    """
    Вычисляет частоту имен собственных, состоящих из одного токена, без соседних имен собственных.

    :param text: Входной текст на русском языке.
    :param show_analysis: Флаг, определяющий, нужно ли выводить анализ в консоль. По умолчанию True.

    :return: Частота одиночных имен собственных в процентах.
    """
    found_entities_str, entities_count = extract_entities(text, False)
    found_entities = ast.literal_eval(found_entities_str)  # Преобразуем строку в список кортежей
    single_entities_count = 0

    for entity, entity_type in found_entities:
        if len(entity.split()) == 1:
            single_entities_count += 1

    single_entities_frequency = round(single_entities_count / entities_count * 100, 3) if entities_count > 0 else 0.0
    if show_analysis:
        print(Fore.GREEN + Style.BRIGHT + "\nОТНОШЕНИЕ ОДНОТОКЕННЫХ ИМЕНОВАННЫХ СУЩНОСТЕЙ КО ВСЕМ "
                                                   "ИМЕНОВАННЫМ СУЩНОСТЯМ"
                                                   "\n                           (SINGLE NAMING)" + Fore.RESET)
        table = Table()

        table.add_column("Параметр", style="bold")
        table.add_column("Значение", justify="center", width=22)

        table.add_row("Отношение (%)", f"{single_entities_frequency:.2f}%")
        table.add_row("Количество одиночных именованных сущностей", str(single_entities_count))
        table.add_row("Общее количество именованных сущностей", str(entities_count))

        console.print(table)
        wait_for_enter_to_analyze()
    return single_entities_frequency


if __name__ == "__main__":
    # Текст для примера (сгенерирован ИИ)
    text = """В огромном городе, где небоскрёбы касались облаков, жила девушка по имени Лиза. Она работала в 
    необычной организации под названием "Луч Света". Эта организация ставила перед собой амбициозную цель — помочь 
    каждому человеку на Земле и сделать мир добрее. Каждое утро Лиза приходила в светлый офис, наполненный зелёными 
    растениями и солнечными лучами, проникающими через огромные окна. Она садилась за свой стол и начинала день с 
    того, что проверяла письма и сообщения от людей со всего мира. Кто-то нуждался в помощи с оплатой медицинских 
    счетов, кто-то искал поддержку в трудную минуту, а кто-то просто хотел поделиться своей радостью. Однажды Лиза 
    получила письмо от маленькой девочки из далёкой деревни. Девочка писала, что её мама тяжело больна, 
    и она не знает, как ей помочь. Лиза немедленно связалась с коллегами, и вскоре команда врачей отправилась в ту 
    самую деревню, чтобы оказать необходимую помощь. Через несколько недель пришло радостное сообщение: мама девочки 
    пошла на поправку. Но "Луч Света" занимался не только экстренной помощью. Они организовывали образовательные 
    программы для детей из бедных семей, строили парки и школы, проводили акции по защите окружающей среды. Лиза 
    особенно гордилась проектом, который они запустили в Африке: благодаря усилиям команды, в нескольких деревнях 
    появились чистая вода и солнечные батареи. Однажды к ним в офис пришёл пожилой человек. Он выглядел растерянным и 
    усталым. Лиза подошла к нему и узнала, что его зовут Иван. Иван потерял всё: дом, семью, работу. Он чувствовал 
    себя одиноким и беспомощным. Лиза пригласила его в свой кабинет, выслушала его историю и пообещала помочь. В 
    течение нескольких дней команда "Луча Света" нашла для Ивана временное жильё, помогла восстановить документы и 
    устроить его на работу. Иван был бесконечно благодарен и часто заходил в офис, чтобы поделиться своими успехами. 
    Каждый вечер Лиза возвращалась домой с чувством выполненного долга. Она знала, что её работа имеет значение, 
    что люди, которым она помогла, снова верят в добро и справедливость. И хотя задачи, стоящие перед "Лучом Света", 
    казались порой непосильными, Лиза и её коллеги не сдавались. Они верили, что капля добра способна вызвать 
    настоящий океан перемен. Так проходили дни, месяцы и годы. Лиза продолжала работать в "Луче Света", 
    оставаясь верной своей мечте — сделать мир лучше. Она знала, что впереди ещё много вызовов, но с каждым добрым 
    делом, с каждой спасённой жизнью, с каждой улыбкой на лице благодарного человека мир становился чуть светлее и 
    добрее."""

    single_naming_frequency(text)
